"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSurveys = exports.apiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function apiRequest(method, resource, body, query = {}, option = {}) {
    const credentials = await this.getCredentials("formbricksApi");
    let options = {
        baseURL: `${credentials.host}/api/v1`,
        method,
        body,
        qs: query,
        url: resource,
        headers: {
            "x-Api-Key": credentials.apiKey,
        },
    };
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.httpRequestWithAuthentication.call(this, "formbricksApi", options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.apiRequest = apiRequest;
async function getSurveys() {
    const endpoint = "/surveys";
    const responseData = await apiRequest.call(this, "GET", endpoint, {});
    if (!responseData.data) {
        throw new n8n_workflow_1.NodeOperationError(this.getNode(), "No data got returned");
    }
    const returnData = [];
    for (const data of responseData.data) {
        returnData.push({
            name: data.name,
            value: data.id,
        });
    }
    return returnData;
}
exports.getSurveys = getSurveys;
//# sourceMappingURL=GenericFunctions.js.map